# API Request

Make an HTTP GET request and extract data from the JSON response.

## Instructions

Write a Python script that:

1. Make a GET request to `https://httpbin.org/json`.
2. Parse the JSON response.
3. Extract the `slideshow.title` field.
4. Print the title to stdout.
